/*---------------------------------------------------------------------------*
Project: OLV
File: olv_Const.h

Copyright (C) 2009-2013 Nintendo. All rights reserved.

These coded instructions, statements, and computer programs contain
proprietary information of Nintendo of America Inc. and/or Nintendo
Company Ltd., and are protected by Federal copyright law.  They may
not be disclosed to third parties or copied or duplicated in any form,
in whole or in part, without the prior written consent of Nintendo.

 *---------------------------------------------------------------------------*/
#ifndef __OLV_CONST_H_
#define __OLV_CONST_H_

/*! @file
@brief These are constant declarations for the OLV library.
*/

/// <span>nn</span>
namespace nn {

/// <span>olv</span>
namespace olv {

/** @defgroup enum Constants
 *  @{
 */

/*!
@brief Enumerates the moods.
*/
enum Feeling
{
    FEELING_NORMAL,     //!< Not specified.
    FEELING_HAPPY,      //!< Fun.
    FEELING_LIKE,       //!< Cool.
    FEELING_SURPRISED,  //!< Surprised.
    FEELING_FRUSTRATED, //!< Frustrated.
    FEELING_PUZZLED     //!< Stuck.
};

/*!
@brief         Enumerated type representing data types.
*/
enum CommonDataType
{
    COMMON_DATA_TYPE_NONE = 0,
    COMMON_DATA_TYPE_BODY_TEXT,                     //!< Text data.
    COMMON_DATA_TYPE_BODY_TEXT_MAX_LENGTH,          //!< The length of the text data.
    COMMON_DATA_TYPE_BODY_MEMO,                     //!< Handwritten memo data.
    COMMON_DATA_TYPE_FEELING,                       //!< Moods.
    COMMON_DATA_TYPE_APP_DATA,                      //!< Application data.
    COMMON_DATA_TYPE_EXTERNAL_IMAGE,                //!< Attached image data.
    COMMON_DATA_TYPE_EXTERNAL_THUMBNAIL_IMAGE,      //!< Attached thumbnail data.
    COMMON_DATA_TYPE_STAMP,                         //!< Stamp data.
    COMMON_DATA_TYPE_EXTERNAL_URL,                  //!< Attached URL.
    COMMON_DATA_TYPE_TOPIC_TAG,                     //!< Topic data.
    COMMON_DATA_TYPE_SEARCH_KEY,                    //!< Search key.
    COMMON_DATA_TYPE_COMMUNITY_ID,                  //!< Community ID.
    COMMON_DATA_TYPE_POST_ID,                       //!< Post ID.
    COMMON_DATA_TYPE_COMMENT_ID,                    //!< Comment ID.
    COMMON_DATA_TYPE_USER_PID,                      //!< Principal ID.
    COMMON_DATA_TYPE_RESULT                         //!< Result.
};

static const int POST_ID_BUFF_LENGTH = 32;                              //!< The length of the buffer for the post ID, including the terminating null character.
static const int POST_ID_MAX_NUM = 20;                                  //!< The maximum number of post IDs that can be specified when downloading posts.
static const int COMMENT_ID_BUFF_LENGTH = 32;                           //!< The length of the buffer for the comment ID, including the terminating null character.
static const int APP_DATA_BUFF_LENGTH = 1024;                           //!< The size of the buffer for the application data.
static const int BODY_TEXT_MAX_LENGTH = 255;                            //!< The maximum length of the text data, excluding the terminating null character.
static const int BODY_TEXT_BUFF_LENGTH = 256;                           //!< The length of the buffer for the text data, including the terminating null character.
static const int BODY_MEMO_WIDTH = 320;                                 //!< The width of the handwritten memo data.
static const int BODY_MEMO_HEIGHT = 120;                                //!< The height of the handwritten memo data.
static const int BODY_MEMO_BUFF_LENGTH = 4864;                          //!< The buffer size of the handwritten memo data.
static const int COMPRESSED_BODY_MEMO_BUFF_LENGTH = BODY_MEMO_BUFF_LENGTH + 32; //!< The buffer size of the handwritten memo data after compression.
static const int TOPIC_TAG_MAX_LENGTH = 50;                             //!< The maximum length of the topic tag, excluding the terminating null character.
static const int TOPIC_TAG_BUFF_LENGTH = 151 + 1;                       //!< The length of the buffer for the topic tag, including the terminating null character.
static const int SEARCH_KEY_MAX_NUM = 5;                                //!< The maximum number of search keys that can be specified when uploading posts.
static const int SEARCH_KEY_MAX_LENGTH = 50;                            //!< The maximum length of the search key, excluding the terminating null character.
static const int SEARCH_KEY_BUFF_LENGTH = 151 + 1;                      //!< The length of the buffer for the search key, including the terminating null character.
static const int EXTERNAL_URL_BUFF_LENGTH = 256;                        //!< The length of the buffer for the attached URL, including the terminating null character.
static const int EXTERNAL_IMAGE_DATA_MAX_LENGTH = 512 * 1024;           //!< The maximum size of the attached image data.
static const int EXTERNAL_THUMBNAIL_IMAGE_DATA_MAX_LENGTH = 128 * 1024; //!< The maximum size of the attached thumbnail image data.
static const int EXTERNAL_IMAGE_DATA_TOTAL_MAX_LENGTH = 512 * 1024;     //!< The maximum combined size of the attached image data and the attached thumbnail image data.
static const int MII_NICKNAME_BUFF_LENGTH = 32;                         //!< The length of the buffer for the nickname of the Mii character, including the terminating null character.
static const int MII_DATA_BUFF_LENGTH = 96;                             //!< The size of the buffer for the Mii data.
static const int COMMUNITY_CODE_BUFF_LENGTH = 13;                       //!< The length of the buffer for the community code, including the terminating null character.
static const int COMMUNITY_ID_MAX_NUM = 30;                             //!< The maximum number of community IDs that can be specified when downloading community data.
static const u32 COMMUNITY_ID_ALL_OFFICIAL = 0xFFFFFFFF;                //!< Community IDs representing all official communities.
static const u8 LANGUAGE_ID_ALL = 0xFE;                                 //!< Language IDs representing all languages.
static const int TITLE_TEXT_BUFF_LENGTH = 128;                          //!< The length of the buffer for the community name, including the terminating null character.
static const int DESCRIPTION_TEXT_BUFF_LENGTH = 256;                    //!< The length of the buffer for the community description, including the terminating null character.
static const int ICON_DATA_BUFF_LENGTH = 9 * 1024 + 44;                 //!< The size of the buffer for the community icon data.
static const int COMPRESSED_ICON_DATA_BUFF_LENGTH = 9 * 1024 + 44;      //!< The size of the buffer for the community icon data after compression.
static const int ICON_DATA_BUFF_LENGTH_WIIU = 64 * 1024 + 44;           //!< The size of the buffer for the Wii U community icon data.
static const int COMPRESSED_ICON_DATA_BUFF_LENGTH_WIIU = 64 * 1024 + 44;//!< The size of the buffer for the compressed Wii U community icon data.
static const int BANNER_DATA_BUFF_LENGTH = 512 * 1024;                  //!< The size of the buffer for banner data.
static const int URL_BUFF_LENGTH = 2048;                                //!< The length of the buffer for the URL, including the terminating null character.
static const int USER_AGENT_BUFF_LENGTH = 64;                           //!< The length of the buffer for the user agent, including the terminating null character.
static const int PARAM_PACK_BUFF_LENGTH = 512;                          //!< The length of the buffer for the parameter pack, including the terminating null character.
static const int HOST_NAME_BUFF_LENGTH = 256;                           //!< The length of the buffer for the hostname, including the terminating null character.
static const int SYSTEM_ARGS_COMMON_STRING_BUFF_LENGTH = 512;           //!< The length of the buffer for the system argument common strings, including the terminating null character.
static const u32 PORTAL_APP_APPLET_ID = 0x117;                          //!< The applet ID for the Miiverse application.

/// @cond
// Definitions for the constants used in the OLV library (<b>Note:</b> do not use these constants directly in your application.)
static  const u32 MODE_VALUE_START_COMMUNITY = 1;                           // The mode specified when showing a community.
static  const u32 MODE_VALUE_START_POST = 2;                                // The mode specified when showing a post.
static  const u32 MODE_VALUE_START_USER = 3;                                // The mode specified when showing a user.
static  const u32 MODE_VALUE_UPLOAD_POST = 16;                              // The mode specified when making a post.
static  const u32 MODE_VALUE_UPLOAD_COMMENT = 17;                           // The mode specified when making a comment.
static  const u32 MODE_VALUE_UPLOAD_POST_RESULT = 18;                       // The mode specified after uploading a post.
static  const u32 MODE_VALUE_UPLOAD_COMMENT_RESULT = 19;                    // The mode specified after uploading a comment.
static  const u32 UPLOAD_FLAG_VALUE_SPOILER = (1<<0);                       // The flag to specify spoilers.
static  const u32 UPLOAD_FLAG_VALUE_COMMUNITY_POST_TYPE_TEXT = (1<<16);     // Flag specifying whether to allow only text for the body of post data.
static  const u32 UPLOAD_FLAG_VALUE_COMMUNITY_POST_TYPE_MEMO = (1<<17);     // Flag specifying whether to allow only handwritten memos for the body of post data.
static  const u32 UPLOAD_FLAG_VALUE_COMMUNITY_COMMENT_TYPE_TEXT = (1<<18);  // Flag specifying whether to allow only text for the body of comment data.
static  const u32 UPLOAD_FLAG_VALUE_COMMUNITY_COMMENT_TYPE_MEMO = (1<<19);  // Flag specifying whether to allow only handwritten memos for the body of comment data.
static  const u32 UPLOAD_FLAG_VALUE_PERMISSION_POST = (1<<20);              // Flag specifying whether to prohibit the uploading of posts.
static  const u32 UPLOAD_FLAG_VALUE_PERMISSION_POST_AND_GET = (1<<21);      // Flag specifying whether to prohibit both the uploading and the viewing of posts.
static  const u32 UPLOAD_FLAG_VALUE_PERMISSION_RESTRICT_PLAYER = (1<<22);   // Flag specifying whether to prohibit the uploading of posts, or both the uploading and the viewing of posts, by users who have not played the game.
static  const u32 UPLOAD_FLAG_VALUE_PERMISSION_COMMENT = (1<<23);           // Flag specifying whether to prohibit the uploading of comments under the same conditions if posting is prohibited.
static  const u32 UPLOAD_FLAG_VALUE_APP_STARTABLE = (1<<4);                 // The flag to specify when an application is startable.
static  const u32 UPLOAD_FLAG_VALUE_FREE_FORMAT = (1<<5);                   // The flag to specify for free text.
static  const u32 UPLOAD_FLAG_VALUE_DELETE = (1<<6);                        // The flag to specify when deleting.
static  const u32 DOWNLOAD_FLAG_VALUE_SPOILER = (1<<0);                     // The flag to specify spoilers.
static  const u32 DOWNLOAD_FLAG_VALUE_FREE_FORMAT = (1<<5);                 // The flag to specify free text.
static  const u32 DOWNLOAD_FLAG_VALUE_EMPATHY_ADDED = (1<<7);               // The flag to specify when a Yeah has been given.
static  const u32 DOWNLOAD_FLAG_VALUE_WITH_APP_DATA = (1<<16);              // The flag to specify when application data is included.
static  const u32 DOWNLOAD_FLAG_VALUE_WITH_MII_DATA = (1<<17);              // The flag to specify when Mii data is included.
static  const u32 DOWNLOAD_FLAG_VALUE_WITH_BODY_TEXT = (1<<18);             // The flag to specify when body text data is included.
static  const u32 DOWNLOAD_FLAG_VALUE_WITH_BODY_MEMO = (1<<19);             // The flag to specify when body handwritten memo data is included.
static  const u32 DOWNLOAD_FLAG_VALUE_WITH_EXTERNAL_IMAGE_DATA = (1<<20);   // The flag to specify when attached image data is included.
static  const u32 DOWNLOAD_FLAG_VALUE_WITH_EXTERNAL_URL = (1<<22);          // The flag to specify when an external URL is included.
static  const u32 DOWNLOAD_FLAG_VALUE_WITH_TITLE_TEXT = (1<<23);            // The flag to specify when title text data is included.
static  const u32 DOWNLOAD_FLAG_VALUE_WITH_DESCRIPTION_TEXT = (1<<24);      // The flag to specify when description text data is included.
static  const u32 DOWNLOAD_FLAG_VALUE_WITH_ICON_DATA = (1<<25);             // The flag to specify when icon data is included.
/// @endcond

/** @} */

}   // namespace olv
}   // namespace nn

#endif
