/*---------------------------------------------------------------------------*
Project: OLV
File: olv_TypesConnect.h

Copyright (C) 2009-2013 Nintendo. All rights reserved.

These coded instructions, statements, and computer programs contain
proprietary information of Nintendo of America Inc. and/or Nintendo
Company Ltd., and are protected by Federal copyright law.  They may
not be disclosed to third parties or copied or duplicated in any form,
in whole or in part, without the prior written consent of Nintendo.

 *---------------------------------------------------------------------------*/
#ifndef __OLV_TYPES_CONNECT_H_
#define __OLV_TYPES_CONNECT_H_

/*! @file
@brief      Declaration of types related to OLV connections.
*/

#include <nn/config.h>
#include <nn/types.h>
#include <nn/act.h>
#include <nn/olv/olv_Const.h>

/// <span>nn</span>
namespace nn {

/// <span>olv</span>
namespace olv {

namespace internal 
{
class Main;
}

/*/* @defgroup class Classes
 *  @{
 */

/*!
@brief Represents the parameters when connecting.
*/
class ConnectParam
{
public:
    /*!
@brief Instantiates the object.
    */
    ConnectParam();

    /*!
@brief Reverts parameters to their initial state.
    */
    void Reset();

    /*!
@brief Sets the Miiverse service token.

You must specify this option.

@param[in]  serviceToken        The Miiverse service token. <br />
The maximum number of characters that can be specified is <tt>NN_ACT_INDEPENDENT_SERVICE_TOKEN_SIZE - 1</tt>.
    */
    void SetServiceToken(const char* serviceToken);

    /*!
@brief Sets flags.

This is for future expansion. It is not used currently.

@param[in] flags  Flags (<tt>FLAG_*</tt>).
    */
    void SetFlags(u32 flags);

protected:
    u32 m_Flags;
    char m_ServiceToken[NN_ACT_INDEPENDENT_SERVICE_TOKEN_SIZE];
    NN_PADDING3;
    u8 m_Reserved[768-520];

    friend class nn::olv::internal::Main;
};

/*!
@brief A class that stores the connection results.
*/
class ConnectedData
{
public:
    /*!
@brief Instantiates the object.
    */
    ConnectedData();

    /*!
@brief Reverts parameters to their initial state.
    */
    void Reset();

    /*!
@brief Tests flags.

This is for future expansion. It is not used currently.

@param[in] flags  Flags (<tt>FLAG_*</tt>).

@return Returns <tt>true</tt> if any of the flags are set; returns <tt>false</tt> otherwise.
    */
    bool TestFlags(u32 flags) const;

    /*!
@brief      Gets the hostname.

Note that specifying invalid arguments for this function, such as the following, results in an assert in debug/development versions and the function returning without doing anything in release versions. <br />
- If <tt>NULL</tt> is specified for the <span class="argument">hostName</span> argument.
- If a value less than that of <tt>nn::olv::HOST_NAME_BUFF_LENGTH</tt> is specified for the <span class="argument">hostNameMaxLength</span> argument.

@param[out] hostName            The buffer that stores the hostname.
@param[in]  hostNameMaxLength   The length of the buffer that stores the hostname, including the terminating null character. <br />
Make sure that you specify a size of at least <tt>@ref nn::olv::HOST_NAME_BUFF_LENGTH</tt>.
    */
    void GetHostName(char* hostName, u32 hostNameMaxLength) const;

protected:
    u32 m_Flags;
    char m_ApiHostName[HOST_NAME_BUFF_LENGTH];
    u8 m_Reserved[512-260];

    friend class nn::olv::internal::Main;
};

/** @} */

}   // namespace olv
}   // namespace nn

#endif
