/*---------------------------------------------------------------------------*
Project: OLV
File: olv_TypesDownloadedDataBase.h

Copyright (C) 2009-2013 Nintendo. All rights reserved.

These coded instructions, statements, and computer programs contain
proprietary information of Nintendo of America Inc. and/or Nintendo
Company Ltd., and are protected by Federal copyright law.  They may
not be disclosed to third parties or copied or duplicated in any form,
in whole or in part, without the prior written consent of Nintendo.

 *---------------------------------------------------------------------------*/
#ifndef __OLV_TYPES_DOWNLOADED_DATABASE_H_
#define __OLV_TYPES_DOWNLOADED_DATABASE_H_

/*! @file
@brief      Base class declarations related to OLV download data.
*/

#include <nn/config.h>
#include <nn/types.h>
#include <nn/mii/mii_StoreData.h>
#include <nn/olv/olv_Const.h>
#include <nn/olv/olv_Result.h>
#include <nn/fnd/fnd_DateTime.h>

/// <span>nn</span>
namespace nn {

/// <span>olv</span>
namespace olv {

namespace internal 
{
class Main;
}

/*/* @defgroup class Classes
 *  @{
 */

/// @cond
/*!
@brief A base class for the class that stores the downloaded post data. <br />
This class cannot be used directly in applications.
*/
class DownloadedDataBase
{
protected:
    enum
    {
        FLAG_NONE = 0,
        FLAG_WITH_BODY_TEXT             = DOWNLOAD_FLAG_VALUE_WITH_BODY_TEXT,
        FLAG_WITH_BODY_MEMO             = DOWNLOAD_FLAG_VALUE_WITH_BODY_MEMO,
        FLAG_WITH_EXTERNAL_IMAGE_DATA   = DOWNLOAD_FLAG_VALUE_WITH_EXTERNAL_IMAGE_DATA,
        FLAG_WITH_MII_DATA              = DOWNLOAD_FLAG_VALUE_WITH_MII_DATA,
        FLAG_WITH_EXTERNAL_URL          = DOWNLOAD_FLAG_VALUE_WITH_EXTERNAL_URL,
        FLAG_WITH_APP_DATA              = DOWNLOAD_FLAG_VALUE_WITH_APP_DATA,
        FLAG_EMPATHY_ADDED              = DOWNLOAD_FLAG_VALUE_EMPATHY_ADDED,
        FLAG_FREE_FORMAT                = DOWNLOAD_FLAG_VALUE_FREE_FORMAT,
        FLAG_SPOILER                    = DOWNLOAD_FLAG_VALUE_SPOILER
    };

    DownloadedDataBase();
    bool TestFlags(u32 flags) const;
    u32 GetUserPid() const;
    nn::fnd::DateTime GetPostDate() const;
    s8 GetFeeling() const;
    u32 GetRegionId() const;
    u8 GetPlatformId() const;
    u8 GetLanguageId() const;
    u8 GetCountryId() const;
    void GetExternalUrl(char* externalUrl, u32 externalUrlMaxLength) const;
    void GetMiiData(nn::mii::StoreData* storeData) const;
    void GetMiiNickname(wchar_t* miiNickname, u32 miiNicknameMaxLength) const;
    void GetBodyText(wchar_t* bodyText, u32 bodyTextMaxLength) const;
    void GetBodyMemo(u8* bodyMemo, u32* bodyMemoSize, u32 bodyMemoMaxSize) const;
    void GetTopicTag(wchar_t* topicTag, u32 topicTagMaxLength) const;
    void GetAppData(u8* appData, u32* appDataSize, u32 appDataMaxSize) const;
    u32 GetAppDataSize() const;
    u32 GetExternalImageDataSize() const;
    nn::olv::Result DownloadExternalImageData(void* externalImageData, u32* externalImageDataSize, u32 externalImageDataMaxSize) const;
    u32 GetCommunityId() const;
    u32 GetEmpathyCount() const;
    u32 GetCommentCount() const;
    void GetPostId(char* postId, u32 postIdMaxLength) const;

    u32 m_Flags;
    u32 m_UserPid;
    nn::fnd::DateTime m_PostDate;
    char m_PostId[POST_ID_BUFF_LENGTH];
    u32 m_RegionId;
    s8 m_Feeling;
    u8 m_PlatformId;
    u8 m_LanguageId;
    u8 m_CountryId;
    wchar_t m_BodyText[BODY_TEXT_BUFF_LENGTH];
    u8 m_BodyMemo[BODY_MEMO_BUFF_LENGTH];
    u32 m_BodyMemoSize;
    wchar_t m_TopicTag[TOPIC_TAG_BUFF_LENGTH];
    u8 m_AppData[APP_DATA_BUFF_LENGTH];
    u32 m_AppDataSize;
    char m_ExternalImageUrl[EXTERNAL_URL_BUFF_LENGTH];
    u32 m_ExternalImageSize;
    char m_ExternalUrl[EXTERNAL_URL_BUFF_LENGTH];
    u8 m_MiiData[MII_DATA_BUFF_LENGTH];
    wchar_t m_MiiNickname[MII_NICKNAME_BUFF_LENGTH];
    u32 m_CommunityId;
    u32 m_EmpathyCount;
    u32 m_CommentCount;
    u8 m_Reserved[8192-7456];

    friend class nn::olv::internal::Main;
};
/// @endcond

/** @} */

}   // namespace olv
}   // namespace nn
#endif
