/*---------------------------------------------------------------------------*
Project: OLV
File: olv_TypesInitialize.h

Copyright (C) 2009-2013 Nintendo. All rights reserved.

These coded instructions, statements, and computer programs contain
proprietary information of Nintendo of America Inc. and/or Nintendo
Company Ltd., and are protected by Federal copyright law.  They may
not be disclosed to third parties or copied or duplicated in any form,
in whole or in part, without the prior written consent of Nintendo.

 *---------------------------------------------------------------------------*/
#ifndef __OLV_TYPES_INITIALIZE_H_
#define __OLV_TYPES_INITIALIZE_H_

/*! @file
@brief      Declaration of types related to OLV initialization.
*/

#include <nn/config.h>
#include <nn/types.h>

/// <span>nn</span>
namespace nn {

/// <span>olv</span>
namespace olv {

namespace internal 
{
class Main;
}

/*/* @defgroup class Classes
 *  @{
 */

/*!
@brief Represents the parameters when initializing the OLV library.
*/
class InitializeParam
{
public:
    /*!
@brief Instantiates the object.
    */
    InitializeParam();

    /*!
@brief Reverts parameters to their initial state.
    */
    void Reset();

    /*!
@brief Sets flags.

This is for future expansion. It is not used currently.

@param[in] flags  Flags (<tt>FLAG_*</tt>).
    */
    void SetFlags(u32 flags);

    /*!
@brief Gets the size of the working buffer the OLV library uses.

Call this function after all of the various parameters have been specified, with the exception of the <tt>@ref SetWork</tt> function. <br />
This function returns fixed values.

@return Returns the size of the working buffer the OLV library uses.
    */
    u32 GetWorkSize() const;

    /*!
@brief  Sets the working buffer for the OLV library.

You must specify this option. <br />
Specify a buffer of at least the size obtained with the <tt>@ref GetWorkSize</tt> function. <br />
This buffer cannot be destroyed at the point the call to the <tt>@ref nn::olv::Initialize</tt> function finishes. See the description of the <tt>@ref nn::olv::Initialize</tt> function.

@param[in]  work       The working buffer.
@param[in]  workSize   The size of the working buffer.
    */
    void SetWork(u8* work, u32 workSize);

protected:
    u32 m_Flags;
    u8* m_Work;
    u32 m_WorkSize;
    u8  m_Reserved[64-12];

    friend class nn::olv::internal::Main;
};

/*!
@brief The class that stores the results when the OLV library is initialized.
*/
class InitializedData
{
public:
    /*!
@brief Instantiates the object.
    */
    InitializedData();

    /*!
@brief Reverts parameters to their initial state.
    */
    void Reset();

protected:
    u32 m_Flags;
    u8 m_Reserved[512-4];

    friend class nn::olv::internal::Main;
};

/** @} */

}   // namespace olv
}   // namespace nn
#endif
