/*---------------------------------------------------------------------------*
Project: OLV
File: olv_TypesUploadEmpathyToPostData.h

Copyright (C) 2009-2013 Nintendo. All rights reserved.

These coded instructions, statements, and computer programs contain
proprietary information of Nintendo of America Inc. and/or Nintendo
Company Ltd., and are protected by Federal copyright law.  They may
not be disclosed to third parties or copied or duplicated in any form,
in whole or in part, without the prior written consent of Nintendo.

 *---------------------------------------------------------------------------*/
#ifndef __OLV_TYPES_UPLOAD_EMPATHY_TO_POSTDATA_H_
#define __OLV_TYPES_UPLOAD_EMPATHY_TO_POSTDATA_H_

/*! @file
@brief      Declaration of types related to giving a Yeah to or removing a Yeah from OLV post data.
*/

#include <nn/config.h>
#include <nn/types.h>
#include <nn/olv/olv_Const.h>

/// <span>nn</span>
namespace nn {

/// <span>olv</span>
namespace olv {

namespace internal 
{
class Main;
}

/*/* @defgroup class Classes
 *  @{
 */

/*!
@brief The class representing the parameters used when uploading a Yeah to a post or removing a Yeah.
*/
class UploadEmpathyToPostDataParam
{
public:
    /*!
@brief Flags that can be specified in the <tt>@ref SetFlags</tt> function.
    */
    enum
    {
        FLAG_NONE = 0,                          //!< This is the state when no flags are specified.
        FLAG_REMOVE = (1<<0)                    //!< Specify this flag when removing a Yeah.
    };

    /*!
@brief Instantiates the object.
    */
    UploadEmpathyToPostDataParam();

    /*!
@brief Reverts parameters to their initial state.
    */
    void Reset();

    /*!
@brief Sets flags.

Specifying this option is not required.

@param[in] flags  Flags (<tt>FLAG_*</tt>).
    */
    void SetFlags(u32 flags);

    /*!
@brief Sets the post ID.

You must specify this option.

@param[in]  postId      The post ID. <br />
The maximum number of characters that can be specified is <tt>@ref nn::olv::POST_ID_BUFF_LENGTH - 1</tt>.
    */
    void SetPostId(const char* postId);

    /*!
@brief Gets the size of the working buffer used by the <tt>@ref nn::olv::UploadEmpathyToPostData</tt> function.

Call this function after all of the various parameters have been specified, with the exception of the <tt>@ref SetWork</tt> function. <br />
This function returns fixed values.

@return Returns the size of the working buffer used by the <tt>@ref nn::olv::UploadEmpathyToPostData</tt> function.
    */
    u32 GetWorkSize() const;

    /*!
@brief Sets the size of the working buffer used by the <tt>@ref nn::olv::UploadEmpathyToPostData</tt> function.

You must specify this option. <br />
Specify a buffer of at least the size obtained with the <tt>@ref GetWorkSize</tt> function. <br />

@param[in]  work       The working buffer.
@param[in]  workSize   The size of the working buffer.
    */
    void SetWork(u8* work, u32 workSize);

private:
    u32 m_Flags;
    u8* m_Work;
    u32 m_WorkSize;
    char m_PostId[POST_ID_BUFF_LENGTH];
    u8 m_Reserved[64-44];

    friend class nn::olv::internal::Main;
};

/** @} */

}   // namespace olv
}   // namespace nn
#endif
