/*---------------------------------------------------------------------------*
  Project:  OLV
  File:     olv_TypesUploadFollowToUserData.h

  Copyright (C) 2009-2013 Nintendo. All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

 *---------------------------------------------------------------------------*/
#ifndef __OLV_TYPES_UPLOAD_FOLLOW_TO_USER_DATA_H_
#define __OLV_TYPES_UPLOAD_FOLLOW_TO_USER_DATA_H_

/*! @file
    @brief      OLV type declarations related to the following of user data.
*/

#include <nn/config.h>
#include <nn/types.h>
#include <nn/olv/olv_Const.h>
#include <nn/olv/olv_Result.h>

/// <span>nn</span>
namespace nn {

/// <span>olv</span>
namespace olv {

namespace internal 
{
class Main;
}

/*/* @defgroup class Classes
 *  @{
 */

/*!
    @brief The class representing the parameters used when following users and canceling the following of users.
*/
class UploadFollowToUserDataParam
{
public:
    /*!
        @brief Flags that can be specified in the <tt>@ref SetFlags</tt> function.
    */
    enum
    {
        FLAG_NONE = 0,                                          //!< This is the state when no flags are specified.
        FLAG_REMOVE = (1<<0)                                    //!< Specify this flag when canceling the following of users.
    };

    /*!
        @brief Instantiates the object.
    */
    UploadFollowToUserDataParam();

    /*!
        @brief Reverts parameters to their initial state.
    */
    void Reset();

    /*!
        @brief Sets flags.

        Specifying this option is not required.

        @param[in] flags  Flags (<tt>FLAG_*</tt>).
    */
    void SetFlags(u32 flags);

    /*!
        @brief Sets the principal ID.

        You must specify this option.

        @param[in]  userPid The principal ID.
    */
    void SetUserPid(u32 userPid);

    /*!
        @brief Gets the size of the working buffer to use with the <tt>@ref nn::olv::UploadFollowToUserData</tt> function.

        Call this function after all of the various parameters have been specified, with the exception of the <tt>@ref SetWork</tt> function. <br />

        @return Returns the size of the working buffer to use with the <tt>@ref nn::olv::UploadFollowToUserData</tt> function.
    */
    u32 GetWorkSize() const;

    /*!
        @brief Specifies the working buffer to use with the <tt>@ref nn::olv::UploadFollowToUserData</tt> function.

        You must specify this option. <br />
        Specify a buffer of at least the size obtained with the <tt>GetWorkSize</tt> function. <br />

        @param[in]  work       The working buffer.
        @param[in]  workSize   The size of the working buffer.
    */
    void SetWork(u8* work, u32 workSize);

private:
    u32 m_Flags;
    u8* m_Work;
    u32 m_WorkSize;
    u32 m_UserPid;
    u8 m_Reserved[64-16];

    friend class nn::olv::internal::Main;
};

/** @} */

}   // namespace olv
}   // namespace nn
#endif
