﻿/*---------------------------------------------------------------------------*
  Project:  OLV
  File:     common.h

  Copyright (C) 2009-2013 Nintendo. All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

 *---------------------------------------------------------------------------*/

#ifndef NN_SAMPLE_DEMOS_OLV_SAMPLE_COMMON_H_
#define NN_SAMPLE_DEMOS_OLV_SAMPLE_COMMON_H_

const int FONT_SIZE = 8;
const int LINE_WIDTH = 8;
const int LINE_HEIGHT = 8;

// Sets error codes from external.
void OLVDemo_SetErrorCode(u32 errorCode);

// Performs error handling.
void OLVDemo_ErrorHandling(const nn::olv::Result& result);

// Gets whether the OLV library can be used later.
bool OLVDemo_IsOlvEnabled();

// Allocates heap for the demo.
u8* OLVDemo_AllocateMemory(u32 size);

// Deallocates heap that was for the demo.
void OLVDemo_FreeMemory(void* ptr);

// Reads file.
// The content of the file is set to outBuffer, and the size of the file is set to readSize.
// outBuffer is being saved by OLVDemo_AllocateMemory, so deallocate it with OLVDemo_FreeMemory after it has been used.
// 
bool OLVDemo_ReadFile(const char* fileName, void*& outBuffer, size_t& readSize);

// Prints the binary information.
void OLVDemo_PrintBinary(u8* data, u32 num = 8);

// Prints the date and time.
void OLVDemo_PrintDate(nn::fnd::DateTime date);

// Prints the wide character string.
void OLVDemo_PrintWideStr(const wchar_t* str, u32 num = 0);

// Specifies whether to get the service token, and whether to call the connection function inside the demo application.
void OLVDemo_SetIsConnect(bool isConnect);
    
// Gets the service token.
const char* OLVDemo_GetServiceToken();

// This is the structure for simple handling of memory in the demo.
struct OLVDemo_MemoryManager
{
    u8* buf;        // Pointer for the allocated buffer.

    OLVDemo_MemoryManager() : buf(NULL) {}
    ~OLVDemo_MemoryManager() { Free(); }
    u8* Allocate(u32 size) { buf = OLVDemo_AllocateMemory(size); return buf; }
    void Free() { if (buf) { OLVDemo_FreeMemory(buf); buf = NULL; } }
};

// This is the structure for simple handling of file associations in the demo.
struct OLVDemo_FileManager
{
    const char* fileName; // Pointer for the filename.
    void* data;           // Buffer that stores the contents of the file.
    size_t size;          // File size.

    OLVDemo_FileManager() : fileName(NULL), data(NULL), size(0){}
    ~OLVDemo_FileManager() { Release(); } 
    bool Read(const char *name) { fileName = name; return OLVDemo_ReadFile(fileName, data, size); }
    void Release() { if (data) { OLVDemo_FreeMemory(data); data = NULL; size = 0; } }
    const char* GetFileName() const { return fileName; }
};


#endif
